@@ -11,15 +11,11 @@ import pytest
 
 
 class test_object_properties(unittest.TestCase):
-
     def test_error_raised_when_enrichment_and_enrichment_target(self):
-
         def error_raised_correctly():
 
             test_material = nmm.Material.from_library(
-                name="WC",
-                enrichment=90,
-                enrichment_target=None
+                name="WC", enrichment=90, enrichment_target=None
             )
             test_material.openmc_material
 
@@ -30,8 +26,7 @@ class test_object_properties(unittest.TestCase):
         selectivly propagated to the openmc_material and that the density
         remains unchanged"""
 
-        test_mat = nmm.Material.from_library(
-            "FLiBe", temperature=80, pressure=1)
+        test_mat = nmm.Material.from_library("FLiBe", temperature=80, pressure=1)
 
         assert test_mat.temperature == 80
         assert test_mat.openmc_material.temperature == 80
@@ -40,7 +35,8 @@ class test_object_properties(unittest.TestCase):
             name="FLiBe",
             temperature=80,
             pressure=1,
-            temperature_to_neutronics_code=False)
+            temperature_to_neutronics_code=False,
+        )
 
         assert test_mat_2.temperature == 80
         assert test_mat_2.openmc_material.temperature is None
@@ -51,30 +47,26 @@ class test_object_properties(unittest.TestCase):
         selectivly propagated to the serpent_material and that the density
         remains unchanged"""
 
-        test_mat = nmm.Material.from_library(
-            name="FLiBe",
-            temperature=180,
-            pressure=2)
+        test_mat = nmm.Material.from_library(name="FLiBe", temperature=180, pressure=2)
 
         assert test_mat.temperature == 180
         assert test_mat.openmc_material.temperature == 180
-        assert test_mat.serpent_material.split('\n')[0].endswith(' tmp 180')
+        assert test_mat.serpent_material.split("\n")[0].endswith(" tmp 180")
 
         test_mat_2 = nmm.Material.from_library(
             name="FLiBe",
             temperature=180,
             pressure=1,
-            temperature_to_neutronics_code=False)
+            temperature_to_neutronics_code=False,
+        )
 
         assert test_mat_2.temperature == 180
         assert test_mat_2.openmc_material.temperature is None
-        assert test_mat_2.serpent_material.split(
-            '\n')[0].endswith(' tmp 180') is False
+        assert test_mat_2.serpent_material.split("\n")[0].endswith(" tmp 180") is False
         assert test_mat.openmc_material.density == test_mat_2.openmc_material.density
 
     def test_density_of_material_is_set_from_equation(self):
-        test_mat = nmm.Material.from_library(
-            "FLiBe", temperature=80, pressure=1)
+        test_mat = nmm.Material.from_library("FLiBe", temperature=80, pressure=1)
         assert test_mat.density is not None
 
     def test_density_of_material_is_set_from_crystal(self):
@@ -159,20 +151,18 @@ class test_object_properties(unittest.TestCase):
         dict_of_fispact_mats = {}
         for entry in line_by_line_material:
             isotope_and_fraction = entry.split()
-            dict_of_fispact_mats[isotope_and_fraction[0]
-                                 ] = float(isotope_and_fraction[1])
+            dict_of_fispact_mats[isotope_and_fraction[0]] = float(
+                isotope_and_fraction[1]
+            )
 
-        assert dict_of_fispact_mats['Li6'] == pytest.approx(3.537400925715E+21)
-        assert dict_of_fispact_mats['Li7'] == pytest.approx(4.307481314353E+22)
-        assert dict_of_fispact_mats['Si28'] == pytest.approx(
-            1.074757396925E+22)
-        assert dict_of_fispact_mats['Si29'] == pytest.approx(
-            5.457311411014E+20)
-        assert dict_of_fispact_mats['Si30'] == pytest.approx(
-            3.597484069651E+20)
-        assert dict_of_fispact_mats['O16'] == pytest.approx(4.650130496709E+22)
-        assert dict_of_fispact_mats['O17'] == pytest.approx(1.766602913225E+19)
-        assert dict_of_fispact_mats['O18'] == pytest.approx(9.324307302413E+19)
+        assert dict_of_fispact_mats["Li6"] == pytest.approx(3.537400925715e21)
+        assert dict_of_fispact_mats["Li7"] == pytest.approx(4.307481314353e22)
+        assert dict_of_fispact_mats["Si28"] == pytest.approx(1.074757396925e22)
+        assert dict_of_fispact_mats["Si29"] == pytest.approx(5.457311411014e20)
+        assert dict_of_fispact_mats["Si30"] == pytest.approx(3.597484069651e20)
+        assert dict_of_fispact_mats["O16"] == pytest.approx(4.650130496709e22)
+        assert dict_of_fispact_mats["O17"] == pytest.approx(1.766602913225e19)
+        assert dict_of_fispact_mats["O18"] == pytest.approx(9.324307302413e19)
 
     def test_fispact_material_with_volume(self):
         test_mat = nmm.Material.from_library("Li4SiO4", volume_in_cm3=2.0)
@@ -185,20 +175,18 @@ class test_object_properties(unittest.TestCase):
         dict_of_fispact_mats = {}
         for entry in line_by_line_material:
             isotope_and_fraction = entry.split()
-            dict_of_fispact_mats[isotope_and_fraction[0]
-                                 ] = float(isotope_and_fraction[1])
+            dict_of_fispact_mats[isotope_and_fraction[0]] = float(
+                isotope_and_fraction[1]
+            )
 
-        assert dict_of_fispact_mats['Li6'] == pytest.approx(7.074801851431E+21)
-        assert dict_of_fispact_mats['Li7'] == pytest.approx(8.614962628707E+22)
-        assert dict_of_fispact_mats['Si28'] == pytest.approx(
-            2.149514793849E+22)
-        assert dict_of_fispact_mats['Si29'] == pytest.approx(
-            1.091462282203E+21)
-        assert dict_of_fispact_mats['Si30'] == pytest.approx(
-            7.194968139301E+20)
-        assert dict_of_fispact_mats['O16'] == pytest.approx(9.300260993419E+22)
-        assert dict_of_fispact_mats['O17'] == pytest.approx(3.533205826449E+19)
-        assert dict_of_fispact_mats['O18'] == pytest.approx(1.864861460483E+20)
+        assert dict_of_fispact_mats["Li6"] == pytest.approx(7.074801851431e21)
+        assert dict_of_fispact_mats["Li7"] == pytest.approx(8.614962628707e22)
+        assert dict_of_fispact_mats["Si28"] == pytest.approx(2.149514793849e22)
+        assert dict_of_fispact_mats["Si29"] == pytest.approx(1.091462282203e21)
+        assert dict_of_fispact_mats["Si30"] == pytest.approx(7.194968139301e20)
+        assert dict_of_fispact_mats["O16"] == pytest.approx(9.300260993419e22)
+        assert dict_of_fispact_mats["O17"] == pytest.approx(3.533205826449e19)
+        assert dict_of_fispact_mats["O18"] == pytest.approx(1.864861460483e20)
 
     def test_mcnp_material_suffix(self):
         test_material1 = nmm.Material.from_library(
@@ -209,8 +197,7 @@ class test_object_properties(unittest.TestCase):
             name="Nb3Sn", zaid_suffix=".30c", material_id=27
         )
         mcnp_material2 = test_material2.mcnp_material
-        test_material3 = nmm.Material.from_library(
-            name="Nb3Sn", material_id=27)
+        test_material3 = nmm.Material.from_library(name="Nb3Sn", material_id=27)
         mcnp_material3 = test_material3.mcnp_material
 
         assert len(mcnp_material3) < len(mcnp_material2)
@@ -340,12 +327,10 @@ class test_object_properties(unittest.TestCase):
         assert "-" in line_by_line_material[11]
 
     def test_serpent_material_suffix(self):
-        test_material1 = nmm.Material.from_library(
-            name="Nb3Sn", zaid_suffix=".21c")
+        test_material1 = nmm.Material.from_library(name="Nb3Sn", zaid_suffix=".21c")
         serpent_material1 = test_material1.serpent_material
 
-        test_material2 = nmm.Material.from_library(
-            name="Nb3Sn", zaid_suffix=".30c")
+        test_material2 = nmm.Material.from_library(name="Nb3Sn", zaid_suffix=".30c")
         serpent_material2 = test_material2.serpent_material
 
         test_material3 = nmm.Material.from_library(name="Nb3Sn")
@@ -389,8 +374,7 @@ class test_object_properties(unittest.TestCase):
         assert len(line_by_line_material) == 12
         assert line_by_line_material[0].split()[0] == "mat"
         assert line_by_line_material[0].split()[1] == "Nb3Sn"
-        assert float(line_by_line_material[0].split()[
-                     2]) == pytest.approx(3.3333)
+        assert float(line_by_line_material[0].split()[2]) == pytest.approx(3.3333)
         assert "      041093.30c  7.5000e-01" in line_by_line_material
         assert "      050120.30c  8.1450e-02" in line_by_line_material
         assert "      050119.30c  2.1475e-02" in line_by_line_material
@@ -409,8 +393,7 @@ class test_object_properties(unittest.TestCase):
         li_fraction = 7
         enrichment = 20
 
-        lithium_lead_elements = "Li" + \
-            str(li_fraction) + "Pb" + str(pb_fraction)
+        lithium_lead_elements = "Li" + str(li_fraction) + "Pb" + str(pb_fraction)
         test_material = nmm.Material.from_library(
             "lithium-lead",
             enrichment=enrichment,
@@ -434,10 +417,8 @@ class test_object_properties(unittest.TestCase):
             if entry[0] == "Li7":
                 li7_atom_count = li7_atom_count + entry[1]
         print(nucs)
-        assert pb_atom_count == pytest.approx(
-            pb_fraction / (pb_fraction + li_fraction))
-        assert li_atom_count == pytest.approx(
-            li_fraction / (pb_fraction + li_fraction))
+        assert pb_atom_count == pytest.approx(pb_fraction / (pb_fraction + li_fraction))
+        assert li_atom_count == pytest.approx(li_fraction / (pb_fraction + li_fraction))
         assert li6_atom_count * 4.0 == pytest.approx(li7_atom_count)
 
         assert li6_atom_count == pytest.approx(
@@ -445,8 +426,7 @@ class test_object_properties(unittest.TestCase):
             rel=0.01,
         )
         assert li7_atom_count == pytest.approx(
-            ((100.0 - enrichment) / 100) *
-            (li_fraction / (pb_fraction + li_fraction)),
+            ((100.0 - enrichment) / 100) * (li_fraction / (pb_fraction + li_fraction)),
             rel=0.01,
         )
 
@@ -456,8 +436,7 @@ class test_object_properties(unittest.TestCase):
         li_fraction = 7
         enrichment = 20
 
-        lithium_lead_elements = "Li" + \
-            str(li_fraction) + "Pb" + str(pb_fraction)
+        lithium_lead_elements = "Li" + str(li_fraction) + "Pb" + str(pb_fraction)
         test_material = nmm.Material.from_library(
             "lithium-lead",
             enrichment=enrichment,
@@ -497,44 +476,34 @@ class test_object_properties(unittest.TestCase):
         # however, this could be becuase the density values are rounded to 2 dp
 
         test_mat = nmm.Material.from_library(name="Li4SiO4")
-        assert test_mat.openmc_material.density == pytest.approx(
-            2.32, rel=0.01)
+        assert test_mat.openmc_material.density == pytest.approx(2.32, rel=0.01)
 
         test_mat = nmm.Material.from_library(name="Li2SiO3")
-        assert test_mat.openmc_material.density == pytest.approx(
-            2.44, rel=0.01)
+        assert test_mat.openmc_material.density == pytest.approx(2.44, rel=0.01)
 
         test_mat = nmm.Material.from_library(name="Li2ZrO3")
-        assert test_mat.openmc_material.density == pytest.approx(
-            4.03, rel=0.01)
+        assert test_mat.openmc_material.density == pytest.approx(4.03, rel=0.01)
 
         test_mat = nmm.Material.from_library(name="Li2TiO3")
-        assert test_mat.openmc_material.density == pytest.approx(
-            3.34, rel=0.01)
+        assert test_mat.openmc_material.density == pytest.approx(3.34, rel=0.01)
 
         test_mat = nmm.Material.from_library(name="Li8PbO6")
-        assert test_mat.openmc_material.density == pytest.approx(
-            4.14, rel=0.01)
+        assert test_mat.openmc_material.density == pytest.approx(4.14, rel=0.01)
 
         test_mat = nmm.Material.from_library(name="Be")
-        assert test_mat.openmc_material.density == pytest.approx(
-            1.88, rel=0.01)
+        assert test_mat.openmc_material.density == pytest.approx(1.88, rel=0.01)
 
         test_mat = nmm.Material.from_library(name="Be12Ti")
-        assert test_mat.openmc_material.density == pytest.approx(
-            2.28, rel=0.01)
+        assert test_mat.openmc_material.density == pytest.approx(2.28, rel=0.01)
 
         test_mat = nmm.Material.from_library(name="Ba5Pb3")
-        assert test_mat.openmc_material.density == pytest.approx(
-            5.84, rel=0.01)
+        assert test_mat.openmc_material.density == pytest.approx(5.84, rel=0.01)
 
         test_mat = nmm.Material.from_library(name="Nd5Pb4")
-        assert test_mat.openmc_material.density == pytest.approx(
-            8.79, rel=0.01)
+        assert test_mat.openmc_material.density == pytest.approx(8.79, rel=0.01)
 
         test_mat = nmm.Material.from_library(name="Zr5Pb3")
-        assert test_mat.openmc_material.density == pytest.approx(
-            8.23, rel=0.01)
+        assert test_mat.openmc_material.density == pytest.approx(8.23, rel=0.01)
 
         #  TODO extra checks for all the crystals needed here
 
@@ -547,15 +516,16 @@ class test_object_properties(unittest.TestCase):
             enrichment_target="Li6",
             enrichment_type="ao",
         )
-        assert (test_mat.openmc_material.density >
-                test_mat_enriched.openmc_material.density)
+        assert (
+            test_mat.openmc_material.density > test_mat_enriched.openmc_material.density
+        )
 
     def test_density_of_packed_crystals(self):
 
         test_mat = nmm.Material.from_library(name="Li4SiO4")
         test_mat_packed = nmm.Material.from_library(
-            name="Li4SiO4",
-            packing_fraction=0.35)
+            name="Li4SiO4", packing_fraction=0.35
+        )
         assert (
             test_mat.openmc_material.density * 0.35
             == test_mat_packed.openmc_material.density
@@ -566,8 +536,7 @@ class test_object_properties(unittest.TestCase):
         pb_fraction = 3
         li_fraction = 7
 
-        lithium_lead_elements = "Li" + \
-            str(li_fraction) + "Pb" + str(pb_fraction)
+        lithium_lead_elements = "Li" + str(li_fraction) + "Pb" + str(pb_fraction)
         test_material = nmm.Material.from_library(
             "lithium-lead",
             chemical_equation=lithium_lead_elements,
@@ -581,13 +550,10 @@ class test_object_properties(unittest.TestCase):
                 pb_atom_count = pb_atom_count + entry[1]
             if entry[0].startswith("Li"):
                 li_atom_count = li_atom_count + entry[1]
-        assert pb_atom_count == pytest.approx(
-            pb_fraction / (pb_fraction + li_fraction))
-        assert li_atom_count == pytest.approx(
-            li_fraction / (pb_fraction + li_fraction))
+        assert pb_atom_count == pytest.approx(pb_fraction / (pb_fraction + li_fraction))
+        assert li_atom_count == pytest.approx(li_fraction / (pb_fraction + li_fraction))
 
     def test_incorrect_settings(self):
-
         def enrichment_too_high():
             """checks a ValueError is raised when enrichment is over 100"""
 
@@ -627,16 +593,14 @@ class test_object_properties(unittest.TestCase):
             """checks a ValueError is raised when the both chemical_equation and elements are used"""
 
             nmm.Material.from_library(
-                name='my_mat',
+                name="my_mat",
                 enrichment=50.0,
                 chemical_equation="Li4SiO4",
-                elements={'C': 0.3333, 'O': 0.666},
+                elements={"C": 0.3333, "O": 0.666},
                 enrichment_type="ao",
             )
 
-        self.assertRaises(
-            ValueError,
-            incorrect_elements_chemical_equation_usage)
+        self.assertRaises(ValueError, incorrect_elements_chemical_equation_usage)
 
         def incorrect_enrichment_target():
             """checks a ValueError is raised when the enrichment target is not a natural isotope"""
@@ -683,9 +647,9 @@ class test_object_properties(unittest.TestCase):
         def test_incorrect_name_type():
             """checks a ValueError is raised when the temperature is not set"""
 
-            test_material = nmm.Material.from_library("H2O",
-                                                      temperature=283,
-                                                      pressure=-1e6)
+            test_material = nmm.Material.from_library(
+                "H2O", temperature=283, pressure=-1e6
+            )
             test_material.name = 1
 
         self.assertRaises(ValueError, test_incorrect_name_type)
@@ -694,9 +658,8 @@ class test_object_properties(unittest.TestCase):
             """checks a ValueError is raised when the temperature is not set"""
 
             nmm.Material.from_library(
-                "eurofer",
-                density=1.,
-                density_unit='grams per cm3')
+                "eurofer", density=1.0, density_unit="grams per cm3"
+            )
 
         self.assertRaises(ValueError, test_incorrect_density_unit_type)
 
@@ -704,9 +667,8 @@ class test_object_properties(unittest.TestCase):
             """checks a ValueError is raised when the temperature is not set"""
 
             nmm.Material.from_library(
-                "eurofer",
-                density=1.,
-                percent_type='weight percent')
+                "eurofer", density=1.0, percent_type="weight percent"
+            )
 
         self.assertRaises(ValueError, test_incorrect_percent_type_type)
 
@@ -714,45 +676,36 @@ class test_object_properties(unittest.TestCase):
             """checks a ValueError is raised when the temperature is not set"""
 
             nmm.Material.from_library(
-                "eurofer",
-                density=1.,
-                enrichment_type='weight percent')
+                "eurofer", density=1.0, enrichment_type="weight percent"
+            )
 
         self.assertRaises(ValueError, test_incorrect_enrichment_type_type)
 
         def test_incorrect_atoms_per_unit_cell():
             """checks a ValueError is raised when the temperature is not set"""
 
-            nmm.Material.from_library(
-                "eurofer",
-                atoms_per_unit_cell=-1.)
+            nmm.Material.from_library("eurofer", atoms_per_unit_cell=-1.0)
 
         self.assertRaises(ValueError, test_incorrect_atoms_per_unit_cell)
 
         def test_incorrect_volume_of_unit_cell_cm3():
             """checks a ValueError is raised when the temperature is not set"""
 
-            nmm.Material.from_library(
-                "eurofer",
-                volume_of_unit_cell_cm3=-1.)
+            nmm.Material.from_library("eurofer", volume_of_unit_cell_cm3=-1.0)
 
         self.assertRaises(ValueError, test_incorrect_volume_of_unit_cell_cm3)
 
         def test_incorrect_temperature():
             """checks a ValueError is raised when the temperature is not set"""
 
-            nmm.Material.from_library(
-                "eurofer",
-                temperature=-1.)
+            nmm.Material.from_library("eurofer", temperature=-1.0)
 
         self.assertRaises(ValueError, test_incorrect_temperature)
 
         def test_incorrect_zaid_suffix_type():
             """checks a ValueError is raised when the temperature is not set"""
 
-            nmm.Material.from_library(
-                "eurofer",
-                zaid_suffix=0.80)
+            nmm.Material.from_library("eurofer", zaid_suffix=0.80)
 
         self.assertRaises(ValueError, test_incorrect_zaid_suffix_type)
 
@@ -760,10 +713,7 @@ class test_object_properties(unittest.TestCase):
             """checks a ValueError is raised when the packing_fraction is the
             wrong type"""
 
-            nmm.Material.from_library(
-                "eurofer",
-                packing_fraction="1"
-            )
+            nmm.Material.from_library("eurofer", packing_fraction="1")
 
         self.assertRaises(ValueError, test_incorrect_packing_fraction)
 
@@ -771,10 +721,7 @@ class test_object_properties(unittest.TestCase):
             """checks a ValueError is raised when the packing_fraction is the
             too large"""
 
-            nmm.Material.from_library(
-                "eurofer",
-                packing_fraction=1.1
-            )
+            nmm.Material.from_library("eurofer", packing_fraction=1.1)
 
         self.assertRaises(ValueError, test_too_large_packing_fraction)
 
@@ -782,10 +729,7 @@ class test_object_properties(unittest.TestCase):
             """checks a ValueError is raised when the packing_fraction is the
             too large"""
 
-            nmm.Material.from_library(
-                "eurofer",
-                packing_fraction=-0.1
-            )
+            nmm.Material.from_library("eurofer", packing_fraction=-0.1)
 
         self.assertRaises(ValueError, test_too_small_packing_fraction)
 
@@ -793,10 +737,7 @@ class test_object_properties(unittest.TestCase):
             """checks a ValueError is raised when the chemical_equation is the
             not a str"""
 
-            nmm.Material.from_library(
-                "eurofer",
-                chemical_equation=-0.1
-            )
+            nmm.Material.from_library("eurofer", chemical_equation=-0.1)
 
         self.assertRaises(ValueError, test_chemical_equation_wrong_type)
 
@@ -805,9 +746,7 @@ class test_object_properties(unittest.TestCase):
             too large"""
 
             nmm.Material.from_library(
-                "Li4SiO4",
-                enrichment=101,
-                enrichment_target='Li6'
+                "Li4SiO4", enrichment=101, enrichment_target="Li6"
             )
 
         self.assertRaises(ValueError, test_enrichment_too_high)
@@ -816,11 +755,7 @@ class test_object_properties(unittest.TestCase):
             """checks a ValueError is raised when the enrichment is the
             too small"""
 
-            nmm.Material.from_library(
-                "Li4SiO4",
-                enrichment=-1,
-                enrichment_target='Li6'
-            )
+            nmm.Material.from_library("Li4SiO4", enrichment=-1, enrichment_target="Li6")
 
         self.assertRaises(ValueError, test_enrichment_too_low)
 
@@ -828,10 +763,7 @@ class test_object_properties(unittest.TestCase):
             """checks a ValueError is raised when the pressure is the
             too small"""
 
-            nmm.Material.from_library(
-                "Li4SiO4",
-                pressure=-1
-            )
+            nmm.Material.from_library("Li4SiO4", pressure=-1)
 
         self.assertRaises(ValueError, test_pressure_too_low)
 
@@ -839,10 +771,7 @@ class test_object_properties(unittest.TestCase):
             """checks a ValueError is raised when the comment is the
             not a string"""
 
-            nmm.Material.from_library(
-                "Li4SiO4",
-                comment=-1
-            )
+            nmm.Material.from_library("Li4SiO4", comment=-1)
 
         self.assertRaises(ValueError, test_comment_wrong_type)
 
@@ -850,10 +779,7 @@ class test_object_properties(unittest.TestCase):
             """checks a ValueError is raised when the material_id is the
             not an int"""
 
-            nmm.Material.from_library(
-                "Li4SiO4",
-                material_id='one'
-            )
+            nmm.Material.from_library("Li4SiO4", material_id="one")
 
         self.assertRaises(ValueError, test_material_id_wrong_type)
 
@@ -970,49 +896,43 @@ class test_object_properties(unittest.TestCase):
 
     def test_json_dump_works(self):
         test_material = nmm.Material.from_library(
-            name="H2O", temperature=373, pressure=1e6)
+            name="H2O", temperature=373, pressure=1e6
+        )
         assert isinstance(json.dumps(test_material), str)
 
     def test_json_dump_contains_correct_keys(self):
         test_material = nmm.Material.from_library(
-            name="H2O", temperature=373, pressure=1e6, comment='test')
+            name="H2O", temperature=373, pressure=1e6, comment="test"
+        )
         test_material_in_json_form = test_material.to_json()
 
-        assert "density" in test_material_in_json_form['H2O'].keys()
-        assert "density_unit" in test_material_in_json_form['H2O'].keys()
-        assert "chemical_equation" in test_material_in_json_form['H2O'].keys()
-        assert "packing_fraction" in test_material_in_json_form['H2O'].keys()
-        assert "percent_type" in test_material_in_json_form['H2O'].keys()
-        assert "pressure" in test_material_in_json_form['H2O'].keys()
-        assert "comment" in test_material_in_json_form['H2O'].keys()
-        assert "temperature" in test_material_in_json_form['H2O'].keys()
+        assert "density" in test_material_in_json_form["H2O"].keys()
+        assert "density_unit" in test_material_in_json_form["H2O"].keys()
+        assert "chemical_equation" in test_material_in_json_form["H2O"].keys()
+        assert "packing_fraction" in test_material_in_json_form["H2O"].keys()
+        assert "percent_type" in test_material_in_json_form["H2O"].keys()
+        assert "pressure" in test_material_in_json_form["H2O"].keys()
+        assert "comment" in test_material_in_json_form["H2O"].keys()
+        assert "temperature" in test_material_in_json_form["H2O"].keys()
 
     def test_json_dump_contains_correct_keys_2(self):
-        test_material = nmm.Material.from_library(
-            name="Li4SiO4", enrichment=90)
+        test_material = nmm.Material.from_library(name="Li4SiO4", enrichment=90)
         test_material_in_json_form = test_material.to_json()
 
-        assert "atoms_per_unit_cell" in test_material_in_json_form['Li4SiO4'].keys(
-        )
-        assert "density" in test_material_in_json_form['Li4SiO4'].keys()
-        assert "density_unit" in test_material_in_json_form['Li4SiO4'].keys()
-        assert "chemical_equation" in test_material_in_json_form['Li4SiO4'].keys(
-        )
-        assert "enrichment_type" in test_material_in_json_form['Li4SiO4'].keys(
-        )
-        assert "packing_fraction" in test_material_in_json_form['Li4SiO4'].keys(
-        )
-        assert "percent_type" in test_material_in_json_form['Li4SiO4'].keys()
-        assert "comment" in test_material_in_json_form['Li4SiO4'].keys()
-        assert "enrichment" in test_material_in_json_form['Li4SiO4'].keys()
-        assert "enrichment_target" in test_material_in_json_form['Li4SiO4'].keys(
-        )
-        assert "volume_of_unit_cell_cm3" in test_material_in_json_form['Li4SiO4'].keys(
-        )
+        assert "atoms_per_unit_cell" in test_material_in_json_form["Li4SiO4"].keys()
+        assert "density" in test_material_in_json_form["Li4SiO4"].keys()
+        assert "density_unit" in test_material_in_json_form["Li4SiO4"].keys()
+        assert "chemical_equation" in test_material_in_json_form["Li4SiO4"].keys()
+        assert "enrichment_type" in test_material_in_json_form["Li4SiO4"].keys()
+        assert "packing_fraction" in test_material_in_json_form["Li4SiO4"].keys()
+        assert "percent_type" in test_material_in_json_form["Li4SiO4"].keys()
+        assert "comment" in test_material_in_json_form["Li4SiO4"].keys()
+        assert "enrichment" in test_material_in_json_form["Li4SiO4"].keys()
+        assert "enrichment_target" in test_material_in_json_form["Li4SiO4"].keys()
+        assert "volume_of_unit_cell_cm3" in test_material_in_json_form["Li4SiO4"].keys()
 
     def test_json_dump_contains_correct_values(self):
-        test_material = nmm.Material.from_library(
-            "H2O", temperature=373, pressure=1e6)
+        test_material = nmm.Material.from_library("H2O", temperature=373, pressure=1e6)
         test_material_in_json_form = test_material.to_json()
 
         assert test_material_in_json_form["H2O"]["pressure"] == 1e6
@@ -1024,9 +944,7 @@ class test_object_properties(unittest.TestCase):
         attribute of the openmc materials"""
 
         test_material = nmm.Material.from_library(
-            'H2O',
-            temperature=383,
-            pressure=15.5e6
+            "H2O", temperature=383, pressure=15.5e6
         )
 
         assert test_material.temperature == 383
@@ -1042,9 +960,7 @@ class test_object_properties(unittest.TestCase):
         attribute of the openmc materials"""
 
         test_material = nmm.Material.from_library(
-            'H2O',
-            temperature=300,
-            pressure=15.5e6
+            "H2O", temperature=300, pressure=15.5e6
         )
 
         assert test_material.temperature == 300
@@ -1059,7 +975,7 @@ class test_object_properties(unittest.TestCase):
         """checks that the temperature set in K ends up in the temperature
         attribute of the openmc materials"""
 
-        test_material = nmm.Material.from_library('WC')
+        test_material = nmm.Material.from_library("WC")
         assert test_material.openmc_material.temperature is None
 
         line_by_line_material = test_material.serpent_material.split("\n")
@@ -1072,10 +988,7 @@ class test_object_properties(unittest.TestCase):
         """Test that arbitrary commands cannot be injected."""
         with pytest.raises(NameError):
             nmm.Material.from_library(
-                name="Nb3Sn",
-                temperature=373,
-                pressure=1e6,
-                density="os.system('ls')"
+                name="Nb3Sn", temperature=373, pressure=1e6, density="os.system('ls')"
             )
 
 
